==> webkit2gtk_2.50.0.orig.tar.xz: webkitgtk-2.50.0/Source/WebKit/WebProcess/GPU/graphics/ImageBufferRemoteDisplayListBackend.h <==
/*
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/NullImageBufferBackend.h>
#include <wtf/TZoneMalloc.h>

namespace WebKit {

class RemoteRenderingBackendProxy;

class ImageBufferRemoteDisplayListBackend : public WebCore::NullImageBufferBackend {
    WTF_MAKE_TZONE_OR_ISO_ALLOCATED(ImageBufferRemoteDisplayListBackend);
    WTF_MAKE_NONCOPYABLE(ImageBufferRemoteDisplayListBackend);
public:
    static std::unique_ptr<ImageBufferRemoteDisplayListBackend> create(const Parameters&);

    virtual ~ImageBufferRemoteDisplayListBackend();

    static constexpr WebCore::RenderingMode renderingMode = WebCore::RenderingMode::DisplayList;

private:
    ImageBufferRemoteDisplayListBackend(const Parameters&);

    RefPtr<WebCore::NativeImage> createNativeImageReference() override;
    String debugDescription() const override;
};

} // namespace WebKit

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/WebKit/WebProcess/GPU/graphics/ImageBufferRemoteDisplayListBackend.h <==
/*
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/NullImageBufferBackend.h>
#include <wtf/TZoneMalloc.h>

namespace WebKit {

class RemoteRenderingBackendProxy;

class ImageBufferRemoteDisplayListBackend : public WebCore::NullImageBufferBackend {
    WTF_MAKE_TZONE_ALLOCATED(ImageBufferRemoteDisplayListBackend);
    WTF_MAKE_NONCOPYABLE(ImageBufferRemoteDisplayListBackend);
public:
    static std::unique_ptr<ImageBufferRemoteDisplayListBackend> create(const Parameters&);

    virtual ~ImageBufferRemoteDisplayListBackend();

    static constexpr WebCore::RenderingMode renderingMode = WebCore::RenderingMode::DisplayList;

private:
    ImageBufferRemoteDisplayListBackend(const Parameters&);

    RefPtr<WebCore::NativeImage> createNativeImageReference() override;
    String debugDescription() const override;
};

} // namespace WebKit
